@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-10-10 01:23:29 jcs>
+/* Time-stamp: <2006-02-28 20:04:37 jcs>
 |
 |  Copyright (C) 2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -28,7 +28,7 @@
 |
 |
 |
-|  $Id: ipod-device.c,v 1.11 2005/11/22 12:27:17 teuf Exp $
+|  $Id: ipod-device.c,v 1.17 2006/02/28 11:06:09 jcsjcs Exp $
 */
 /* ex: set ts=4: */
 /***************************************************************************
@@ -169,6 +169,7 @@ static const IpodModel ipod_model_table [] = {
 	
 	/* HP iPods, need contributions for this table */
 	{"E436", 40 * GB, MODEL_TYPE_REGULAR, FOURTH_GENERATION},
+	{"S492", 30 * GB, MODEL_TYPE_COLOR, FOURTH_GENERATION},
 	
 	{NULL, 0, 0, 0}
 };
@@ -529,37 +530,43 @@ ipod_device_set_property(GObject *object, guint prop_id,
 	gchar **volumes;
 	gint volume_count;
 
+	g_return_if_fail (device);
+
 	switch(prop_id) {
 		case PROP_MOUNT_POINT:
 		case PROP_DEVICE_PATH:
 		case PROP_HAL_VOLUME_ID:
-			str = g_value_get_string(value);
-			volumes = libhal_manager_find_device_string_match(
-				device->priv->hal_context, "block.device", str, 
+		        str = g_value_get_string(value);
+			volumes = NULL;
+			if (device->priv->hal_context)
+			{
+			    volumes = libhal_manager_find_device_string_match(
+				device->priv->hal_context, "block.device", str,
 				&volume_count, NULL);
-		
-			if(volume_count == 0) {
+			    if(volume_count == 0)
+			    {
 				libhal_free_string_array(volumes);
 				volumes = libhal_manager_find_device_string_match(
-					device->priv->hal_context, "volume.mount_point", 
-					str, &volume_count, NULL);
-				
-				if(volume_count >= 1)
-					str = volumes[0];
-			} else {
+				    device->priv->hal_context, "volume.mount_point",
+				    str, &volume_count, NULL);
+			    }
+			    if(volume_count >= 1)
+			    {
 				str = volumes[0];
+			    }
 			}
 #ifdef HAVE_LIBHAL
 			g_free_if_not_null(device->priv->hal_volume_id);
-			device->priv->hal_volume_id = g_strdup(str);
+			device->priv->hal_volume_id = g_strdup (str);
 #else
 /* JCS for libgpod */
 			g_free (device->priv->mount_point);
 			device->priv->mount_point = g_strdup (str);
 /* end JCS for libgpod */
 #endif
+			if (volumes)
+			    libhal_free_string_array(volumes);
 			device->priv->is_ipod = ipod_device_reload(device);
-			libhal_free_string_array(volumes);	
 			break;
 		case PROP_DEVICE_NAME:
 			str = g_value_get_string(value);
@@ -864,6 +871,7 @@ ipod_device_hal_initialize()
 	libhal_ctx_set_dbus_connection(hal_context, dbus_connection);
 	
 	if(!libhal_ctx_init(hal_context, &error)) {
+		dbus_error_free(&error);
 		libhal_ctx_free(hal_context);
 		return NULL;
 	}
@@ -933,13 +941,15 @@ ipod_device_read_device_info_string(FILE *fd)
 	gunichar2 *utf16;
 	gchar *utf8;
 	
-	fread(&length, 1, sizeof(gshort), fd);
+	if (fread(&length, sizeof(gshort), 1, fd) != 1)
+	        return NULL;
 	
 	if(length <= 0)
 		return NULL;
 	
 	utf16 = (gunichar2 *)g_malloc(length * sizeof(gunichar2));
-	fread(utf16, sizeof(gunichar2), length, fd);
+	if (fread(utf16, sizeof(gunichar2), length, fd) != length)
+		return NULL;
 	
 	if(utf16 == NULL)
 		return NULL;
@@ -957,6 +967,7 @@ ipod_device_write_device_info_string(gchar *str, FILE *fd)
 {
 	gunichar2 *unistr;
 	gshort length;
+	size_t res;
 
 	if(str == NULL)
 		return;
@@ -966,8 +977,9 @@ ipod_device_write_device_info_string(gchar *str, FILE *fd)
 	
 	length = length > 0x198 ? 0x198 : length;
 
-	fwrite(&length, 2, 1, fd);
-	fwrite(unistr, 2, length, fd);
+	/* FIXME: we do not check if the write was successful */
+	res = fwrite(&length, 2, 1, fd);
+	res = fwrite(unistr, 2, length, fd);
 	
 	g_free(unistr);
 }
@@ -1029,6 +1041,7 @@ ipod_device_info_load(IpodDevice *device)
 {
 	gchar *path;
 	FILE *fd;
+	gint intres;
 	
 	g_return_val_if_fail(IS_IPOD_DEVICE(device), FALSE);
 	
@@ -1045,10 +1058,10 @@ ipod_device_info_load(IpodDevice *device)
 	if(device->priv->device_name == NULL)
 		device->priv->device_name = g_strdup("iPod");
 	
-	fseek(fd, 0x200, SEEK_SET);
+	intres=fseek(fd, 0x200, SEEK_SET);
 	device->priv->user_name = ipod_device_read_device_info_string(fd);
 	
-	fseek(fd, 0x400, SEEK_SET);
+	intres=fseek(fd, 0x400, SEEK_SET);
 	device->priv->host_name = ipod_device_read_device_info_string(fd);
 	
 	fclose(fd);
@@ -1116,7 +1129,7 @@ ipod_device_get_model_index_from_table(const gchar *_model_num)
 	gchar *p = model_num;
 	
 	if(isalpha(model_num[0])) 
-		*p++;
+		p++;
 	
 	for(i = 2; ipod_model_table[i].model_number != NULL; i++) {
 		if(g_strncasecmp(p, ipod_model_table[i].model_number, 4) == 0) {
@@ -1682,6 +1695,8 @@ ipod_device_save(IpodDevice *device, GError **error_out)
 	gchar *path, *itunes_dir;
 	gchar bs = 0;
 	GError *error = NULL;
+	size_t res;
+	gint intres;
 	
 	g_return_val_if_fail(IS_IPOD_DEVICE(device), FALSE);
 	
@@ -1723,11 +1738,12 @@ ipod_device_save(IpodDevice *device, GError **error_out)
 	fseek(fd, 0x200, SEEK_SET);
 	ipod_device_write_device_info_string(device->priv->user_name, fd);
 	
-	fseek(fd, 0x400, SEEK_SET);
+	intres = fseek(fd, 0x400, SEEK_SET);
 	ipod_device_write_device_info_string(device->priv->host_name, fd);
 	
-	fseek(fd, 0X5FF, SEEK_SET);
-	fwrite(&bs, 1, 1, fd);
+	intres = fseek(fd, 0X5FF, SEEK_SET);
+	/* FIXME: we do not check if the write was successful */
+	res = fwrite(&bs, 1, 1, fd);
 	
 	fclose(fd);
 	
