@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: itdb_playlist.c,v 1.14 2005/11/19 07:30:18 jcsjcs Exp $
+|  $Id: itdb_playlist.c,v 1.15 2006/02/03 18:44:48 jcsjcs Exp $
 */
 
 #include "itdb_private.h"
@@ -782,38 +782,38 @@ void itdb_spl_update (Itdb_Playlist *spl)
 }
 
 
+void spl_update (Itdb_Playlist *playlist, gpointer data);
+void spl_update (Itdb_Playlist *playlist, gpointer data)
+{
+    g_return_if_fail (playlist);
+    itdb_spl_update (playlist);
+}
 
 
 /* update all smart playlists */
 void itdb_spl_update_all (Itdb_iTunesDB *itdb)
 {
-    auto void spl_update (Itdb_Playlist *playlist, gpointer data);
-    void spl_update (Itdb_Playlist *playlist, gpointer data)
-    {
-	g_return_if_fail (playlist);
-	itdb_spl_update (playlist);
-    }
-
     g_return_if_fail (itdb);
 
     g_list_foreach (itdb->playlists, (GFunc)spl_update, NULL);
 }
 
 
+void spl_update2 (Itdb_Playlist *playlist, gpointer data);
+void spl_update2 (Itdb_Playlist *playlist, gpointer data)
+{
+    g_return_if_fail (playlist);
+    if (playlist->is_spl && playlist->splpref.liveupdate)
+        itdb_spl_update (playlist);
+}
+
+
 /* update all smart playlists with 'live updating' set*/
 void itdb_spl_update_live (Itdb_iTunesDB *itdb)
 {
-    auto void spl_update (Itdb_Playlist *playlist, gpointer data);
-    void spl_update (Itdb_Playlist *playlist, gpointer data)
-    {
-	g_return_if_fail (playlist);
-	if (playlist->is_spl && playlist->splpref.liveupdate)
-	    itdb_spl_update (playlist);
-    }
-
     g_return_if_fail (itdb);
 
-    g_list_foreach (itdb->playlists, (GFunc)spl_update, NULL);
+    g_list_foreach (itdb->playlists, (GFunc)spl_update2, NULL);
 }
 
 
